# PT-names 
A package to handle portuguese PT names. Can generate random names and classify gender of a name.

Um pacote para processar nomes portugueses (de Portugal). Consegue gerar nomes aleatórios e classificar se um nome é masculino ou feminino.

